from projectRule.mtk5510.Mtk5510Common import Mtk5510Common


class Ruler(Mtk5510Common):

    # Customer_ID
    _customer_id = 'CUSTOMER_SAMPLE_AUTO_CONFIG'

    # 代码分支
    _code_branch = ''

    # 测试类型
    _test_type = 'F'

    def get_ocs_modelid(self):
        project = self.request_dict[self.ocs_demand.product_name].replace('.', '_')
        modelid = 'CS' + self.ocs_number + '_SAMPLE_' + project + '_ID_PNL_GENERAL' \
                  + '_DUTY_' + self.request_dict[self.ocs_demand.pwm_name]
        return modelid

    def get_ocs_require(self):
        """获取ocs上的配置，生成配置代码
        Args:
            ocs_number：OCS订单号
        Returns:
             返回配置代码
        """
        ret = ''
        _space = 60
        ret += '#elif ( IsModelID('+ self.get_ocs_modelid() + ') )' + '\n'
        ret += '// board & chip & Flash & pwm' + '\n'
        ret += self.get_board_macro()
        ret += self.get_chip_macro()
        ret += self.get_flash_size_macro()
        ret += self.get_pwm_macro()
        ret += self.get_ci_macro()
        ret += self.get_eshare_macro()
        ret += self.get_wifi_macro()
        ret += self.get_ddr_macro()
        ret += self.get_tuner_macro()

        # 因为对于样品订单来说不需要关注遥控器/按键板/logo等的配置项，如果写客户订单的处理逻辑，需要注意这些配置项
        ret += '//ir & keypad & logo' + '\n'
        ret += '#define CVT_DEF_IR_TYPE'.ljust(_space) + 'ID_IR_CVTE_KA84' + '\n'
        ret += '#define CVT_DEF_KEYPAD_TYPE'.ljust(_space) + 'ID_KEYPAD_CVTE_DEFAULT' + '\n'
        ret += '#define CVT_DEF_KEYPAD_ADC'.ljust(_space) + 'ID_KEYPADADC_CVTE1SAR' + '\n'
        ret += '#define CVT_DEF_LOGO_TYPE'.ljust(_space) + 'ID_LOGO_CVTE_DEFAULT' + '\n'

        # 样品订单不需要关注屏幕信息，如果写客户订单的处理逻辑，需要注意
        ret += '// panel & pq' + '\n'
        ret += '#define CVT_DEF_PANEL_NAME'.ljust(_space) + '"PT320AT01_1"' + '\n'
        ret += '#define CVT_DEF_PANEL_TYPE '.ljust(_space) + 'ID_PNL_General_1920_1080' + '\n'
        ret += '#define CVT_DEF_SOUND_TYPE'.ljust(_space) + 'ID_SOUND_AMP_COMMON_DEFAULT_12V8R8W' + '\n'
        ret += '#define CVT_DEF_PQ_TYPE'.ljust(_space) + 'ID_PQ_COMMON_DEFAULT' + '\n'

        ret += '// language & country' + '\n'
        if self._code_branch == 'fae_eu':
            ret += '#define CVT_DEF_LANGUAGE_SELECT'.ljust(_space) + 'ID_LANGUAGE_ENGLISH_US' + '\n'
            ret += '#define CVT_DEF_COUNTRY_SELECT'.ljust(_space) + 'ID_COUNTRY_UKRAINE' + '\n'
            ret += '#define CVT_DEF_MARKET_REGION'.ljust(_space) + 'ID_MARKET_REGION_EU_DVBT' + '\n'
            ret += '#define CVT_DEF_MENU_CONFIG_XML_TYPE'.ljust(_space) + 'ID_MENU_CONFIG_XML_COMMON_EU' + '\n'
        elif self._code_branch == 'fae_sa':
            ret += '#define CVT_DEF_LANGUAGE_SELECT'.ljust(_space) + 'ID_LANGUAGE_SPANISH_ES' + '\n'
            ret += '#define CVT_DEF_COUNTRY_SELECT'.ljust(_space) + 'ID_COUNTRY_BOLIVIA' + '\n'
            ret += '#define CVT_DEF_MARKET_REGION'.ljust(_space) + 'ID_MARKET_REGION_SA_ISDB' + '\n'
            ret += '#define CVT_DEF_MENU_CONFIG_XML_TYPE'.ljust(_space) + 'ID_MENU_CONFIG_XML_CVTE_GOOGLE' + '\n'
        elif self._code_branch == 'fae_us':
            ret += '#define CVT_DEF_LANGUAGE_SELECT'.ljust(_space) + 'ID_LANGUAGE_ENGLISH_US' + '\n'
            ret += '#define CVT_DEF_COUNTRY_SELECT'.ljust(_space) + 'ID_COUNTRY_MEXICO' + '\n'
            ret += '#define CVT_DEF_MARKET_REGION'.ljust(_space) + 'ID_MARKET_REGION_US_ATSC' + '\n'
            ret += '#define CVT_DEF_MENU_CONFIG_XML_TYPE'.ljust(_space) + 'ID_MENU_CONFIG_XML_COMMON_US' + '\n'
        else:
            raise RuntimeError('不支持此区域，请确认，谢谢！')

        ret += '// special request' + '\n'
        # GAIA
        other_app_list = self.request_dict[self.ocs_demand.other_app_soft]
        if 'Gaia 2.0' in other_app_list:
            ret += '#define CVT_DEF_LAUNCHER_TYPE'.ljust(_space) + 'ID_LAUNCHER_30_GAIA_20' + '\n'
            ret += '#define CVT_DEF_LAUNCHER_SKIN_TYPE'.ljust(_space) + 'ID_LAUNCHER_SKIN_30_GAIA_20_CVTE_COMMON' + '\n'
        elif 'Gaia 1.0' in other_app_list:
            ret += '#define CVT_DEF_LAUNCHER_TYPE'.ljust(_space) + 'ID_LAUNCHER_30_GAIA_10' + '\n'
            ret += '#define CVT_DEF_LAUNCHER_SKIN_TYPE'.ljust(_space) + 'ID_LAUNCHER_SKIN_30_CVTE_COMMON' + '\n'
        elif 'Gaia AI' in other_app_list:
            ret += '#define CVT_EN_APP_TV_SPEECH'.ljust(_space) + '1' + '\n'
            ret += '#define CVT_EN_APP_SPOTIFY_TV'.ljust(_space) + '1' + '\n'
            ret += '#define CVT_DEF_LAUNCHER_TYPE'.ljust(_space) + 'ID_LAUNCHER_30_GAIA_20_AI' + '\n'
            ret += '#define CVT_DEF_LAUNCHER_SKIN_TYPE'.ljust(_space) + 'ID_LAUNCHER_SKIN_30_GAIA_20_CVTE_COMMON' + '\n'
        else:
            ret += '#define CVT_DEF_LAUNCHER_TYPE'.ljust(_space) + 'ID_LAUNCHER_20_STARK_OS' + '\n'
            ret += '#define CVT_DEF_LAUNCHER_SKIN_TYPE'.ljust(_space) + 'ID_LAUNCHER_SKIN_COMMON' + '\n'

        ret += '//END\n'
        return ret

















