import requests
from bs4 import BeautifulSoup
from pyocs import pyocs_login


class PyocsConfluence:

    country_tv_system_mapping_table_kb_link = 'https://kb.cvte.com/pages/viewpage.action?pageId=138102551'
    project_code_mapping_table_kb_link = 'https://kb.cvte.com/pages/viewpage.action?pageId=139470654'
    customer_dt_mapping_table_kb_link = 'https://kb.cvte.com/pages/viewpage.action?pageId=139478158'
    engineer_tcl_dt_mapping_table_kb_link = 'https://kb.cvte.com/pages/viewpage.action?pageId=140906075'

    def __init__(self):
        self.account = pyocs_login.PyocsLogin().get_account_from_json_file()

    def get_tv_system_by_country(self, country):
        tv_system = ''
        country_page_content = requests.get(self.country_tv_system_mapping_table_kb_link,
                                            auth=(self.account['Username'], self.account['Password']))
        soup = BeautifulSoup(country_page_content.text, features="lxml")
        country_list = soup.find_all('td', class_="confluenceTd")
        for country_str in country_list:
            if country in str(country_str.string):
                tv_system = country_str.next_sibling.string if country_str.next_sibling else ''
        return tv_system

    def get_country_region_by_country(self, country):
        country_region = ''
        country_page_content = requests.get(self.country_tv_system_mapping_table_kb_link,
                                            auth=(self.account['Username'], self.account['Password']))
        soup = BeautifulSoup(country_page_content.text, features="lxml")
        country_list = soup.find_all('td', class_="confluenceTd")
        for country_str in country_list:
            if country in str(country_str.string):
                country_region = country_str.next_sibling.next_sibling.string if country_str.next_sibling.next_sibling else ''
        return country_region

    def get_country_name_by_country(self, country):
        country_name = ''
        country_page_content = requests.get(self.country_tv_system_mapping_table_kb_link,
                                            auth=(self.account['Username'], self.account['Password']))
        soup = BeautifulSoup(country_page_content.text, features="lxml")
        country_list = soup.find_all('td', class_="confluenceTd")
        for country_str in country_list:
            if country in str(country_str.string):
                country_name = country_str.next_sibling.next_sibling.next_sibling.string if country_str.next_sibling.next_sibling.next_sibling else ''
        return country_name

    def get_code_download_url_by_project(self, tv_project):
        code_url = ''
        country_page_content = requests.get(self.project_code_mapping_table_kb_link,
                                            auth=(self.account['Username'], self.account['Password']))
        soup = BeautifulSoup(country_page_content.text, features="lxml")
        project_list = soup.find_all('td', class_="highlight-grey confluenceTd")
        for project_str in project_list:
            if tv_project in str(project_str.string):
                code_url = project_str.next_sibling.string if project_str.next_sibling else ''
        return code_url

    def get_jenkins_project_by_project(self, tv_project):
        jenkins_project_name = ''
        country_page_content = requests.get(self.project_code_mapping_table_kb_link,
                                            auth=(self.account['Username'], self.account['Password']))
        soup = BeautifulSoup(country_page_content.text, features="lxml")
        project_list = soup.find_all('td', class_="highlight-grey confluenceTd")
        for project_str in project_list:
            if tv_project in str(project_str.string):
                jenkins_project_name = project_str.next_sibling.next_sibling.string if project_str.next_sibling.next_sibling else ''
        return jenkins_project_name

    def get_download_link_of_dt_by_customer(self, customer_name: str):
        dt_download_link = ''
        country_page_content = requests.get(self.customer_dt_mapping_table_kb_link,
                                            auth=(self.account['Username'], self.account['Password']))
        soup = BeautifulSoup(country_page_content.text, features="lxml")
        customer_list = soup.find_all('td', class_="confluenceTd")
        for customer_str in customer_list:
            if customer_name in str(customer_str.string):
                dt_download_link = customer_str.next_sibling.string if customer_str.next_sibling else ''
        return dt_download_link

    def get_download_link_of_tcl_dt_by_engineer(self, engineer_name: str):
        dt_download_link = ''
        country_page_content = requests.get(self.engineer_tcl_dt_mapping_table_kb_link,
                                            auth=(self.account['Username'], self.account['Password']))
        soup = BeautifulSoup(country_page_content.text, features="lxml")
        engineer_list = soup.find_all('td', class_="confluenceTd")
        for engineer_str in engineer_list:
            if engineer_name in str(engineer_str.string):
                dt_download_link = engineer_str.next_sibling.string if engineer_str.next_sibling else ''
        return dt_download_link
