import jenkins
import sys
from pathlib import Path
import os
from pyocs import pyocs_login
import logging
import pkgutil
from pyocs.pyocs_filesystem import PyocsFileSystem
import pprint


class PyocsJenkins:

	jenkins_server = jenkins.Jenkins

	def __init__(self):
		self.jenkins_server = self._create_jenkins_server()

	@staticmethod
	# jenkins采用的账号即为域账号，直接利用Pyocs_Login模块中读取json的方式
	def _create_jenkins_server():
		account = pyocs_login.PyocsLogin().get_account_from_json_file()
		server = jenkins.Jenkins('http://tvci.gz.cvte.cn/', username=account['Username'], password=account['Password'],
								 timeout=30)
		return server

	@staticmethod
	def _get_current_base_name(cur_dir: str):
		"""
		#name:get_current_base_name
		#function:获得当前代码的代码名和分支名
		#return:代码名_B_分支名
		"""
		repo_dir = Path(str(cur_dir) + '/.repo')
		repo_file = Path(str(cur_dir) + '/.repo/manifests.git/config')
		url_line = ''
		branch_line = ''
		if repo_dir.exists():
			with open(str(repo_file), 'r') as f:
				for line in f.readlines():
					if "url" in line:
						url_line = line	 # 获得当前代码名所在行
					if "merge" in line:
						branch_line = line	 # 获得当前代码分支所在行
			split_list = url_line.split('/')
			project_name = split_list[3]
			split_list = branch_line.split(' = ')
			branch_name = split_list[1].strip()
			#code_name = project_name.upper()+'_B_'+branch_name  # (大写)代码名_B_(小写)分支名
			#logging.info(code_name)
			return project_name, branch_name
		else:
			print("此目录非repo仓库，请移步代码仓库的根目录下执行")

	@staticmethod
	def _get_customer_name(cur_dir: str, modle_id: str):
		"""
		#name:get_customer_name
		#function:获得当前MODLE_ID的客户名
		#return:CUSTOMER_XX
		"""
		str_modle_id = modle_id
		if 'CS' in str_modle_id or 'CP' in str_modle_id:
			customer_dir = Path(str(cur_dir) + '/customers/customer/')
			str_grep_cmd = "grep -rIsl " + modle_id + " " + str(customer_dir)
			logging.info(str_grep_cmd)
			file_name = os.popen(str_grep_cmd).read()
			logging.info(file_name)
			if 'customer_' not in file_name:
				raise RuntimeError("未找到此MODLE_ID，请确认输入")
		else:
			raise RuntimeError("请输入正确的modleid")
		split_list = file_name.split("/")
		customer_file_name = split_list[len(split_list)-1].strip()  #  得到customer_xx.h
		customer_name = customer_file_name.split(".")[0].upper()  #  得到CUSTOMER_XX
		return customer_name

	def _get_jenkins_build_list(self):
		build_list = []
		jobs = self.jenkins_server.get_all_jobs()
		# jobs = server.get_jobs(5)
		for job in jobs:
			if(('CLOUD_BUILD' in job['fullname']) & ('CB_S_' in job['fullname'])):
				build_list.append(job['fullname'])
		return build_list

	def _get_jenkins_project_name(self, project: str, branch: str):
		build_list = self._get_jenkins_build_list()
		project_name = ""
		for i in range(0, len(build_list)):
			if project in build_list[i] and branch in build_list[i]:
				project_name = build_list[i]
				break
		return project_name

	def get_param_from_interaction(self, model_id):
		"""
		从Linux命令行用交互的方式获取编译参数，此函数适用于Linux命令行环境
		:param model_id:
		:return:
		"""
		code_root_dir = PyocsFileSystem.get_current_code_root_dir()
		customer_dir = code_root_dir + '/customers'
		project, branch = self._get_current_base_name(cur_dir=code_root_dir)
		print('方案：' + project)
		print('分支：' + branch)
		test_type_tuple = ("N", "A", "B", "C", "D", "E", "F")
		compile_param_dict = {
			'CUSTOMER_ID': 'CUSTOMER_CVTE',
			'MODEL_ID': '',
			'BASELINE_VERSION': '',
			'BUILD_CMD': 'make ocs',
			'UPLOAD_OCS': 'True',
			'TEST_TYPE': 'N',
			'UPLOAD_OCS_MSG_0': 'update software',
			'AUTO_MAKE_BIN': ''
		}
		customer_name = self._get_customer_name(cur_dir=code_root_dir, modle_id=model_id)
		print("CUSTOMER_ID：" + customer_name)
		print("MODEL_ID：" + model_id)
		while 1:
			test_type = input("请输入测试类型（N、A、B、C、D、E、F），默认为N ：")
			if not test_type:
				compile_param_dict['TEST_TYPE'] = "N"
				break
			if any(test_type in tmp for tmp in test_type_tuple):
				compile_param_dict['TEST_TYPE'] = test_type
				break
			print("输入错误，请重新输入!")
		while 1:
			sw_comment = input("请输入软件备注信息(不输入这个就打屎你)：")
			if not sw_comment:
				print("不要忘记软件备注信息哦")
				continue
			else:
				break
		compile_param_dict['CUSTOMER_ID'] = customer_name
		compile_param_dict['MODEL_ID'] = model_id
		baseline_version = PyocsFileSystem.get_baseline_version(customer_dir=customer_dir, customer_id=customer_name)
		print('基线版本：' + baseline_version)
		baseline_name = baseline_version
		compile_param_dict['BASELINE_VERSION'] = baseline_name
		compile_param_dict['UPLOAD_OCS_MSG_0'] = sw_comment
		while 1:
			ret = input("请确认是否做BIN（Y，N），默认为N：")
			if not ret:
				compile_param_dict['AUTO_MAKE_BIN'] = 'False'
				break
			elif ret is 'Y' or ret is 'y':
				compile_param_dict['AUTO_MAKE_BIN'] = 'True'
				break
			elif ret is 'N' or ret is 'n':
				compile_param_dict['AUTO_MAKE_BIN'] = 'False'
				break
			else:
				print('输入错误，请重新输入！！！')
				continue
		pp = pprint.PrettyPrinter(indent=4)
		print("构建参数如下：")
		print("=======================================")
		pp.pprint(compile_param_dict)
		project_name = self._get_jenkins_project_name(project=project, branch=branch)
		print("Jenkins Job：" + project_name)
		print("=======================================")
		return compile_param_dict, project_name

	"""
	#传入model_id ,创建jenkins编译任务
	"""
	def create_jenkins_job(self, model_id):
		compile_param, prject = self.get_param_from_interaction(model_id)
		self._create_jenkins_job(compile_param=compile_param, project_name=prject)

	def get_last_build_url(self, project_name):
		server = self.jenkins_server
		last_build_number = server.get_job_info(project_name)['lastBuild']['number']
		build_info = server.get_build_info(project_name, last_build_number)
		return build_info['url']

	def _create_jenkins_job(self, compile_param, project_name):
		server = self.jenkins_server
		user = server.get_whoami()
		next_build_number = server.get_job_info(project_name)['nextBuildNumber']
		ret = server.build_job(project_name, compile_param)
		job_url = server.get_job_info(project_name)['url']
		print('Jenkins 编译链接：' + job_url + str(next_build_number))
		# print('Hello %s ,Jenkins id:%s start...' % (user['fullName'], ret))

	@staticmethod
	def get_jenkins_mail_signature():
		ret = pkgutil.get_data("pyocs.resource", "mailsignature").decode("utf8")
		return ret
